@@ -1,33 +1,13 @@
 ( cd opt/kde/share/doc/HTML/hu/ark ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ark ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kdf ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kdf ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kdm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kdm ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kpf ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kpf ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/ktuberling ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/ktuberling ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/amor ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/karm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/karm ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kdat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kdat ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kdvi ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kdvi ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kgeo ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kgeo ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kmix ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kmix ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kodo ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kolf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kolf ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kpat ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kpat ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/korn ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/krfb ; rm -rf common )
@@ -36,22 +16,10 @@
 ( cd opt/kde/share/doc/HTML/hu/ksim ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kalzium ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/katomic ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/katomic ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/ksysguard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ksysguard ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kbounce ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kbounce ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kbattleship ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kbattleship ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kaboodle ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kaboodle ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/khangman ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/khangman ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kfloppy ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kfloppy ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/khexedit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/khexedit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kandy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kandy ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kcalc ; rm -rf common )
@@ -60,8 +28,6 @@
 ( cd opt/kde/share/doc/HTML/hu/kdesu ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kcron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kcron ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kedit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kedit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kfind ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kiten ; rm -rf common )
@@ -70,44 +36,22 @@
 ( cd opt/kde/share/doc/HTML/hu/kjots ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kmoon ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/knode ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/knode ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kooka ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kooka ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/ksame ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ksame ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/ktron ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/ktron ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kuser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kuser ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kview ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kwin4 ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kwin4 ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/lskat ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/lskat ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kcoloredit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/klipper ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/klipper ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kompare ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/konsole ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/konsole ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kpackage ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/khelpcenter/quickstart ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/khelpcenter/glossary ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/khelpcenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/khelpcenter/visualdict ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kshisen ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kshisen ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/ksirtet ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ksirtet ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/konquest ; rm -rf common )
@@ -118,14 +62,8 @@
 ( cd opt/kde/share/doc/HTML/hu/kweather ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kmenuedit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kioslave ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kioslave ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/flashkard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/flashkard ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kbackgammon ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kxconfig ; rm -rf common )
@@ -166,6 +104,8 @@
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf doxygen.css )
@@ -180,12 +120,16 @@
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf fdl-license.html )
@@ -256,72 +200,26 @@
 ( cd opt/kde/share/doc/HTML/hu/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kamera ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kasteroids ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kasteroids ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/keduca ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kmessedwords ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kicker ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kicker ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/klines ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/klines ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kmines ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kmines ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/knotes ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/knotes ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kpager ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kpager ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kpaint ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kpaint ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kpoker ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kpoker ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kruler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kruler ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/ksnake ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/ksnake ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kspell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kspell ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/ktimer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ktimer ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/ktouch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ktouch ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kwrite ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kwrite ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/megami ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/megami ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kreversi ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kreversi ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/noatun ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/noatun ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kdebugdialog ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kblackbox ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kblackbox ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kcharselect ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kiconedit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/klettres ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/klettres ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kfouleggs ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kaphorism ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kghostview ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kghostview ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kjumpingcube ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kenolaba ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kenolaba ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kworldclock ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/KRegExpEditor ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/ksokoban ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/ksokoban ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kteatime ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kmathtool ; rm -rf common )
